using System;
using System.Runtime.InteropServices;

/// <summary>
/// EPX-64C API library definitions
/// </summary>
public class EPX64C
{

	//
	// Device status (Return codes)
	//

    public const int EPX64C_OK = 0;
    public const int EPX64C_INVALID_HANDLE = 1;
    public const int EPX64C_DEVICE_NOT_FOUND = 2;
    public const int EPX64C_DEVICE_NOT_OPENED = 3;
    public const int EPX64C_OTHER_ERROR = 4;
    public const int EPX64C_COMMUNICATION_ERROR = 5;
    public const int EPX64C_INVALID_PARAMETER = 6;


	//
	// I/O Port
	//

    public const byte EPX64C_PORT0 = 0x01;
    public const byte EPX64C_PORT1 = 0x02;
    public const byte EPX64C_PORT2 = 0x04;
    public const byte EPX64C_PORT3 = 0x08;
    public const byte EPX64C_PORT4 = 0x10;
    public const byte EPX64C_PORT5 = 0x20;
    public const byte EPX64C_PORT6 = 0x40;
    public const byte EPX64C_PORT7 = 0x80;

	//
	// Counter Mode
	//

	public const int EPX64C_CNT_MODE_1PHASE = 0;
	public const int EPX64C_CNT_MODE_2PHASE = 1;

	//
	// Counter Direction
	//

	public const int EPX64C_CNT_DIR_UP = 0;
	public const int EPX64C_CNT_DIR_DOWN = 1;

	//
	// Counter Control
	//

	public const int EPX64C_CNT_DISABLE = 0;
	public const int EPX64C_CNT_ENABLE = 1;

	//
	// Counter Status
	//

	public const int EPX64C_CNT_STS_OK = 0;
	public const int EPX64C_CNT_STS_OVF = 1;
	public const int EPX64C_CNT_STS_UDF = 2;


	//
	// Device Functions
	//

    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_GetNumberOfDevices (ref int Number);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_GetSerialNumber (int Index, ref int SerialNumber);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_Open (ref System.IntPtr Handle);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_OpenBySerialNumber (int SerialNumber, ref System.IntPtr Handle);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_Close (System.IntPtr Handle);

 	//
	// I/O Port Functions
	//

   [DllImport("EPX64C.dll")]
    public static extern int EPX64C_SetDirection (System.IntPtr Handle, byte Direction);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_GetDirection (System.IntPtr Handle, ref byte Direction);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_OutputPort (System.IntPtr Handle, byte Port, byte Value);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_InputPort (System.IntPtr Handle, byte Port, ref byte Value);

 	//
	// Counter Functions
	//

    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_SetCounterMode (System.IntPtr Handle, int Mode);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_GetCounterMode (System.IntPtr Handle, ref int Mode);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_SetCounterDirection (System.IntPtr Handle, int Direction);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_GetCounterDirection (System.IntPtr Handle, ref int Direction);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_SetCounterControl (System.IntPtr Handle, int Control);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_GetCounterControl (System.IntPtr Handle, ref int Control);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_ResetCounter (System.IntPtr Handle);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_GetCounterStatus (System.IntPtr Handle, ref int Status);
    [DllImport("EPX64C.dll")]
    public static extern int EPX64C_GetCounterValue (System.IntPtr Handle, ref int Value);

}
