/*++

Copyright (c) 2010-2013 ELMOS Co., Ltd.

Module Name:
	EPX64C.h
Abstract:
	EPX-64C API library definitions
Revision History:
	10/07/08	Created.
	11/12/22	Modified response time.
	13/05/01	Support for Windows 8.

--*/

#ifndef EPX64C_H
#define EPX64C_H

#ifdef EPX64C_EXPORTS_
#define EPX64C_API __declspec(dllexport)
#else
#define EPX64C_API __declspec(dllimport)
#endif

//
// Device handle
//
typedef void *EPX64C_HANDLE;

//
// Device status (Return Value)
//
enum {
	EPX64C_OK,
	EPX64C_INVALID_HANDLE,
	EPX64C_DEVICE_NOT_FOUND,
	EPX64C_DEVICE_NOT_OPENED,
	EPX64C_OTHER_ERROR,
	EPX64C_COMMUNICATION_ERROR,
	EPX64C_INVALID_PARAMETER
};

//
// Port
//
#define EPX64C_PORT0	0x01
#define EPX64C_PORT1	0x02
#define EPX64C_PORT2	0x04
#define EPX64C_PORT3	0x08
#define EPX64C_PORT4	0x10
#define EPX64C_PORT5	0x20
#define EPX64C_PORT6	0x40
#define EPX64C_PORT7	0x80

//
// Counter Mode
//
#define EPX64C_CNT_MODE_1PHASE	0
#define EPX64C_CNT_MODE_2PHASE	1

//
// Counter Direction
//
#define EPX64C_CNT_DIR_UP		0
#define EPX64C_CNT_DIR_DOWN		1

//
// Counter Control
//
#define EPX64C_CNT_DISABLE		0
#define EPX64C_CNT_ENABLE		1

//
// Counter Status
//
#define EPX64C_CNT_STS_OK		0
#define EPX64C_CNT_STS_OVF		1
#define EPX64C_CNT_STS_UDF		2

#ifdef __cplusplus
extern "C" {
#endif

//
// Device Functions
//
EPX64C_API int WINAPI EPX64C_GetNumberOfDevices (int *Number);
EPX64C_API int WINAPI EPX64C_GetSerialNumber (int Index, int *SerialNumber);
EPX64C_API int WINAPI EPX64C_Open (EPX64C_HANDLE *Handle);
EPX64C_API int WINAPI EPX64C_OpenBySerialNumber (int SerialNumber, EPX64C_HANDLE *Handle);
EPX64C_API int WINAPI EPX64C_Close (EPX64C_HANDLE Handle);

//
// Port Functions
//
EPX64C_API int WINAPI EPX64C_SetDirection (EPX64C_HANDLE Handle, BYTE Direction);
EPX64C_API int WINAPI EPX64C_GetDirection (EPX64C_HANDLE Handle, BYTE *Direction);
EPX64C_API int WINAPI EPX64C_OutputPort (EPX64C_HANDLE Handle, BYTE Port, BYTE Value);
EPX64C_API int WINAPI EPX64C_InputPort (EPX64C_HANDLE Handle, BYTE Port, BYTE *Value);

//
// Counter Functions
//
EPX64C_API int WINAPI EPX64C_SetCounterMode (EPX64C_HANDLE Handle, int Mode);
EPX64C_API int WINAPI EPX64C_GetCounterMode (EPX64C_HANDLE Handle, int *Mode);
EPX64C_API int WINAPI EPX64C_SetCounterDirection (EPX64C_HANDLE Handle, int Direction);
EPX64C_API int WINAPI EPX64C_GetCounterDirection (EPX64C_HANDLE Handle, int *Direction);
EPX64C_API int WINAPI EPX64C_SetCounterControl (EPX64C_HANDLE Handle, int Control);
EPX64C_API int WINAPI EPX64C_GetCounterControl (EPX64C_HANDLE Handle, int *Control);
EPX64C_API int WINAPI EPX64C_ResetCounter (EPX64C_HANDLE Handle);
EPX64C_API int WINAPI EPX64C_GetCounterStatus (EPX64C_HANDLE Handle, int *Status);
EPX64C_API int WINAPI EPX64C_GetCounterValue (EPX64C_HANDLE Handle, int *Value);

#ifdef __cplusplus
}
#endif

#endif  /* EPX64C_H */